==> estateplat-common-1.2.3-20180319.063459-48-sources.jar: cn/gtmap/estateplat/model/employment/subject/FcjyCyztCyqyglgx.java <==
package cn.gtmap.estateplat.model.employment.subject;

import cn.gtmap.estateplat.model.resources.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2018/3/16
 * @description 从业企业关联关系
 */
@Table(name = "fcjy_cyzt_cyqyglgx")
public class FcjyCyztCyqyglgx implements InsertVo{
    @Id
    private String gxid;//关系id
    private String zqyid;//主企业id
    private String cqyid;//从企业id
    private String gxlx;//关系类型
    private String sfyx;//是否有效
    private Date glsj;//关联时间
    private Date jcsj;//解除时间

    public String getGxid() {
        return gxid;
    }

    public void setGxid(String gxid) {
        this.gxid = gxid;
    }

    public String getZqyid() {
        return zqyid;
    }

    public void setZqyid(String zqyid) {
        this.zqyid = zqyid;
    }

    public String getCqyid() {
        return cqyid;
    }

    public void setCqyid(String cqyid) {
        this.cqyid = cqyid;
    }

    public String getGxlx() {
        return gxlx;
    }

    public void setGxlx(String gxlx) {
        this.gxlx = gxlx;
    }

    public String getSfyx() {
        return sfyx;
    }

    public void setSfyx(String sfyx) {
        this.sfyx = sfyx;
    }

    public Date getGlsj() {
        return glsj;
    }

    public void setGlsj(Date glsj) {
        this.glsj = glsj;
    }

    public Date getJcsj() {
        return jcsj;
    }

    public void setJcsj(Date jcsj) {
        this.jcsj = jcsj;
    }
}

==> estateplat-common-1.2.4-20190312.015045-117-sources.jar: cn/gtmap/estateplat/model/employment/subject/FcjyCyztCyqyglgx.java <==
package cn.gtmap.estateplat.model.employment.subject;

import cn.gtmap.estateplat.model.resources.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2018/3/16
 * @description 从业企业关联关系
 */
@Table(name = "fcjy_cyzt_cyqyglgx")
public class FcjyCyztCyqyglgx implements InsertVo{
    @Id
    private String gxid;//关系id
    private String zqyid;//主企业id
    private String cqyid;//从企业id
    private String gxlx;//关系类型
    private String sfyx;//是否有效
    private Date glsj;//关联时间
    private Date jcsj;//解除时间
    private String glzt;//关联状态


    public String getGxid() {
        return gxid;
    }

    public void setGxid(String gxid) {
        this.gxid = gxid;
    }

    public String getZqyid() {
        return zqyid;
    }

    public void setZqyid(String zqyid) {
        this.zqyid = zqyid;
    }

    public String getCqyid() {
        return cqyid;
    }

    public void setCqyid(String cqyid) {
        this.cqyid = cqyid;
    }

    public String getGxlx() {
        return gxlx;
    }

    public void setGxlx(String gxlx) {
        this.gxlx = gxlx;
    }

    public String getSfyx() {
        return sfyx;
    }

    public void setSfyx(String sfyx) {
        this.sfyx = sfyx;
    }

    public Date getGlsj() {
        return glsj;
    }

    public void setGlsj(Date glsj) {
        this.glsj = glsj;
    }

    public Date getJcsj() {
        return jcsj;
    }

    public void setJcsj(Date jcsj) {
        this.jcsj = jcsj;
    }

    public String getGlzt() {
        return glzt;
    }

    public void setGlzt(String glzt) {
        this.glzt = glzt;
    }
}
